@@ -8,9 +8,9 @@ use Log::ger;
 use Perinci::Object;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-10-13'; # DATE
+our $DATE = '2022-09-08'; # DATE
 our $DIST = 'App-PDFUtils'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 our %SPEC;
 
@@ -518,7 +518,7 @@ App::PDFUtils - Command-line utilities related to PDF files
 
 =head1 VERSION
 
-This document describes version 0.009 of App::PDFUtils (from Perl distribution App-PDFUtils), released on 2021-10-13.
+This document describes version 0.010 of App::PDFUtils (from Perl distribution App-PDFUtils), released on 2022-09-08.
 
 =head1 SYNOPSIS
 
@@ -537,6 +537,8 @@ files:
 
 =item * L<pdfgrep>
 
+=item * L<pdfnopass>
+
 =item * L<remove-pdf-password>
 
 =back
@@ -816,13 +818,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2017 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2022, 2021, 2020, 2017 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
